@@ -9,7 +9,6 @@ See U{http://www.cs.berkeley.edu/~jordan/papers/vdp-icml.pdf}.
 """
 
 from numpy import array, zeros, ones, dot, empty, exp, log, where, outer, isfinite, empty_like
-from numpy.random import dirichlet, multinomial
 from scipy.special import digamma, gammaln
 from scipy.stats import beta
 from infpy.exp import DirichletExpFamily
@@ -89,6 +88,7 @@ class VariationalDistribution(object):
         """
         Randomise the variational parameters.
         """
+        from numpy.random import dirichlet
         self.phi = dirichlet(ones(self.K), size=self.N)
         self.tau = outer(ones(self.K), self._lambda)
         self.gamma[:,0] = 1.
@@ -295,6 +295,7 @@ def polya_urn(N, alpha):
     spread the draws over more components.
     @return: A vector of counts. The i'th entry represents how many draws were made from the i'th component
     """
+    from numpy.random import multinomial
     assert alpha >= 0.
     counts = []
     for n in xrange(N):
